#
# spec file for package python-PasteScript
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# Namespace package issues break tests on Factory
%if 0%{?suse_version} > 1320
%bcond_with tests
%else
%bcond_without tests
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-PasteScript
Version:        2.0.2
Release:        bp155.2.11
Url:            http://pythonpaste.org/script/
Summary:        A pluggable command-line frontend to setup package file layouts
License:        MIT
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/P/PasteScript/PasteScript-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module Paste >= 1.3}
BuildRequires:  %{python_module PasteDeploy}
%if %{with tests}
# Test requirements
BuildRequires:  %{python_module nose >= 0.11}
BuildRequires:  python-Cheetah
BuildRequires:  python-unittest2
%endif
Requires:       python-Paste >= 1.3
Requires:       python-PasteDeploy
Requires:       python-setuptools
Requires:       python-six
%ifpython2
Recommends:     python-Cheetah
Provides:       %{oldpython}-pastescript = %{version}
Obsoletes:      %{oldpython}-pastescript < %{version}
%endif
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This is a pluggable command-line tool. It includes some built-in features:

  * Create file layouts for packages.
  * Serving up web applications, with configuration based on paste.deploy

%prep
%setup -q -n PasteScript-%{version}
mv docs/_build docs/html # Proper name for HTML docs
sed -i "1d" tests/test_logging_config.py # Fix non-executable script

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests # Remove wrongly installed tests

# Prepare for update-alternatives usage
%python_clone -a %{buildroot}%{_bindir}/paster

%if %{with tests}
%check
%python_expand nosetests-%{$python_bin_suffix} -v tests/
%endif

%post
%python_install_alternative paster

%preun
%python_uninstall_alternative paster

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst docs/license.txt docs/news.txt
%doc docs/html/
%python_alternative %{_bindir}/paster
%{python_sitelib}/PasteScript-%{version}-py*.egg-info
%{python_sitelib}/PasteScript-%{version}-py*-nspkg.pth
%{python_sitelib}/paste/script/

%changelog
* Fri May  5 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Source url must be https.
* Fri Apr 14 2017 toddrme2178@gmail.com
- Update to version 2.0.2
- Remove upstream-included ianb-pastescript-a19e462769b4.diff
- Implement single-spec version
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Jun 11 2012 saschpe@suse.de
- Require 'python-cheetah' on SLE_11_SP2, 'python-Cheetah' elsewhere
* Tue Mar  6 2012 bwiedemann@suse.com
- drop groups properly (fixes bnc#748875)
* Wed Feb  1 2012 saschpe@suse.de
- Remove wrongly installed tests
- Update to version 1.7.5:
  * Import CherryPy directly instead of including its server inline
    in the paste.script package. You must install CherryPy before
    using egg:PasteScript#cherrypy
* Thu Sep  1 2011 saschpe@suse.de
- Renamed from python-pastescript to python-PasteScript
- Added proper changelog file
* Mon Aug 10 2009 cfarrell1980@gmail.com
- Incorporate some changes from Luke Macken
* Wed Dec  3 2008 jfunk@funktronics.ca
- Update to 1.7.3
  * CherryPy wsgiserver updated to 3.1.1, fixes a regression in Python
    2.5 plus a couple other small fixes.
- 1.7.2
  * Fix a packaging issue that could cause problems when installing
    PasteScript.
- 1.7.1
  * filemaker.py's FileOp can now handle a tuple as a source_dir argument that
    should function the same as the _template_dir option for pkg_resources.
  * CherryPy wsgiserver updated to trunk@2063 for Python 2.6
    compatibility.
- 1.7
  * _template_dir now takes a tuple argument, which should be the
    package name, and the relative location to the package of its template
    directory. pkg_resources will then be used to load make the templates
    rather than raw file access making it zip-safe.
  * CherryPy wsgiserver updated to the 3.1.0 release's.
  * Support Python 2.6.
  * Added experimental support for a quicker paster serve --reload for
    Jython.
  * Non-Python files in ``paste/script/templates/`` causes an error on
    2.6; renamed directory to avoid this.
- 1.6.3
  * Fixes for ``paste.script.filemaker``
  * A setuptools ``egg_info.writers`` entry point is now provided that's
    responsible for writing paster_plugins.txt for projects that define
    a new ``paster_plugins`` setup() keyword. paster_plugins.txt will
    still be created for new projects that need it and lack a
    ``paster_plugins`` setup() keyword, but this is deprecated. Projects
    defining ``paster_plugins`` in setup() should also define a
    ``setup_requires`` setup() keyword including PasteScript.
  * An ``egg_plugins`` variable (a list of strings based off the
    Templates classes' ``egg_plugins`` variables) is now available to
    paster create templates for the new ``paster_plugins`` setup()
    keyword.
  * PasteScript is no longer included in
    ``egg_plugins``/paster_plugins.txt by default.
* Fri Nov 14 2008 cfarrell1980@gmail.com
- apply patch to fix LaxTemplate in copydir.py - 1.6.2-2
* Tue Nov 11 2008 cfarrell1980@gmail.com
- try building with --record-rpm instead of --record - 1.6.2-1
* Wed Mar 19 2008 jfunk@funktronics.ca
- Update to 1.6.2:
  * Fix SkipTemplate (could raise ``TypeError: argument 1 must be string
    or read-only buffer, not None`` before)
- 1.6.1 (and 1.6.1.1)
  * Fix paster serve under Windows.
- 1.6
  * Added commands ``paster request config.ini URL`` and ``paster post
    config.ini URL < post-body``, that allow you to do artificial
    requests to applications.
  * Check the writability of the pid and log files earlier.  This caused
    particular problems if you started it in daemon mode, and the files
    weren't writable.  From Chris Atlee.
  * Start the monitor (when using ``--monitor``) after daemonizing, so
    that ``paster serve --monitor --daemon`` works (before it would
    constantly restart).
  * In Paste Script templates, you can give ``should_echo=False`` in
    variable definitions, and if the user is queried for the variable
    then the input will not be echoed (as for a password).  From Dirceu
    Pereira Tiegs.
  * Added a method
    ``paste.script.appinstall.Installer.template_renderer``, which can
    be used to override template substitution with ``paster
    make-config``.  The function is similar to the same function used
    with ``paster create`` templates.
  * Remove ``--daemon`` option from Windows, as it depends on
    ``os.fork``
  * When using ``paster create`` and inserting text with a ``-*-``
    marker, multi-line text will no longer be reinserted.
  * Improved output when skipping templates with ``paster create``.
  * When starting a server with ``paster serve --daemon`` and the pid
    file exists and describes a running process, do not start another
    process.
  * Added ``umask`` option to
    ``egg:PasteScript#flup_fcgi_thread/fork``.
  * Deprecate the flup entry points, as flup now has the necessary entry
    points in its own package.
* Sun Nov  4 2007 jfunk@funktronics.ca
- Initial release
